@@ -1,24 +1,21 @@
-use std::fs::File;
-
-use clap::Clap;
-use exocore_core::cell::{LocalNode, LocalNodeConfigExt};
+use exocore_core::cell::LocalNode;
 use exocore_protos::core::{LocalNodeConfig, NodeAddresses};
 
 use crate::{term::*, Context};
 
-#[derive(Clap)]
+#[derive(clap::Parser)]
 pub struct NodeOptions {
     #[clap(subcommand)]
     pub command: NodeCommand,
 }
 
-#[derive(Clap)]
+#[derive(clap::Parser)]
 pub enum NodeCommand {
     /// Initializes the node.
     Init(InitOptions),
 }
 
-#[derive(Clap)]
+#[derive(clap::Parser)]
 pub struct InitOptions {
     /// Name of the node.
     #[clap(long)]
@@ -32,32 +29,28 @@ pub fn handle_cmd(ctx: &Context, node_opts: &NodeOptions) -> anyhow::Result<()>
 }
 
 fn cmd_init(ctx: &Context, init_opts: &InitOptions) -> anyhow::Result<()> {
-    let config_path = ctx.options.conf_path();
-    if config_path.exists() {
+    let node_dir = ctx.options.node_directory();
+    if LocalNode::config_exists(node_dir.clone()) {
         panic!(
-            "Cannot initialize node. A file already exists at '{:?}'",
-            config_path
+            "Cannot initialize node. A node configuration already exists in '{:?}'",
+            node_dir.as_os_path().unwrap()
         );
     }
 
     print_step("Initializing node directory");
-    let home_path = ctx.options.dir_path();
-    if !home_path.exists() {
-        print_action(format!("Creating directory {}", style_value(&home_path)));
-        std::fs::create_dir_all(home_path).expect("Couldn't create home directory");
-    }
+    let local_node =
+        LocalNode::generate_in_directory(node_dir).expect("Couldn't generate local node");
 
-    let local_node = LocalNode::generate();
     let node = local_node.node();
-
-    let mut node_name = node.name().to_string();
-    if init_opts.name.is_none() {
+    let node_name = if let Some(name) = init_opts.name.as_ref() {
+        name.clone()
+    } else {
         print_spacer();
-        node_name = dialoguer::Input::with_theme(ctx.dialog_theme.as_ref())
+        dialoguer::Input::with_theme(ctx.dialog_theme.as_ref())
             .with_prompt("Enter the name of the node")
             .default(node.name().to_string())
-            .interact_text()?;
-    }
+            .interact_text()?
+    };
 
     // generate port randomly
     let port_rand = 10 + rand::random::<u8>() % 90;
@@ -82,12 +75,10 @@ fn cmd_init(ctx: &Context, init_opts: &InitOptions) -> anyhow::Result<()> {
         ..local_node.config().clone()
     };
 
-    print_action(format!(
-        "Writing configuration to {}",
-        style_value(&config_path)
-    ));
-    let config_file = File::create(&config_path)?;
-    local_node_config.to_yaml_writer(config_file)?;
+    print_action("Writing node configuration");
+    local_node
+        .save_config(&local_node_config)
+        .expect("Couldn't save local node config");
 
     print_success(format!(
         "Node {} with public key {} created",
